@@ -8,11 +8,13 @@ from robot.parsing.model.blocks import Keyword, Section, TestCase
 from robot.parsing.model.statements import Statement
 from robot.variables import search_variable
 
+from robotcode.core.language import language_id
 from robotcode.core.lsp.types import (
     DocumentSymbol,
     SymbolInformation,
     SymbolKind,
 )
+from robotcode.core.text_document import TextDocument
 from robotcode.core.utils.logging import LoggingDescriptor
 from robotcode.robot.utils.ast import (
     range_from_node,
@@ -21,8 +23,6 @@ from robotcode.robot.utils.ast import (
 )
 from robotcode.robot.utils.visitor import Visitor
 
-from ...common.decorators import language_id
-from ...common.text_document import TextDocument
 from .protocol_part import RobotLanguageServerProtocolPart
 
 if TYPE_CHECKING:
@@ -87,14 +87,14 @@ class _Visitor(Visitor):
         self.generic_visit_current_symbol(node, symbol)
 
     def visit_TestCase(self, node: TestCase) -> None:  # noqa: N802
-        if node.name is None:
+        if not node.name:
             return
 
         if self.current_symbol is not None and self.current_symbol.children is not None:
             r = range_from_node(node)
             symbol = DocumentSymbol(
                 name=node.name,
-                kind=SymbolKind.METHOD,
+                kind=SymbolKind.CLASS,
                 range=r,
                 selection_range=r,
                 children=[],
@@ -104,7 +104,7 @@ class _Visitor(Visitor):
             self.generic_visit_current_symbol(node, symbol)
 
     def visit_Keyword(self, node: Keyword) -> None:  # noqa: N802
-        if node.name is None:
+        if not node.name:
             return
 
         if self.current_symbol is not None and self.current_symbol.children is not None:
